// Config: parse config.yaml

// Copyright (C) 2021  Simon Ruderich
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package config

import (
	"fmt"
	"os"

	"gopkg.in/yaml.v2"

	"ruderich.org/simon/safcm"
)

type Config struct {
	DryRun    bool           `yaml:"-"` // set via command line
	Quiet     bool           `yaml:"-"` // set via command line
	LogLevel  safcm.LogLevel `yaml:"-"` // set via command line
	SshConfig string         `yaml:"-"` // set via command line

	DetectGroups  []string `yaml:"detect_groups"`
	GroupPriority []string `yaml:"group_priority"`
}

func LoadConfig() (*Config, error) {
	const path = "config.yaml"

	var cfg Config
	x, err := os.ReadFile(path)
	if err != nil {
		// This file is optional
		if os.IsNotExist(err) {
			return &cfg, nil
		}
		return nil, err
	}
	err = yaml.UnmarshalStrict(x, &cfg)
	if err != nil {
		return nil, fmt.Errorf("%s: failed to load: %v", path, err)
	}
	return &cfg, nil
}
